# bookman

bookman is a non-webapp, standalone bookmark managing software. It gives you the ability to store any link you want and open it instantly.


## Dependencies

* Python 3
* Python 3 - GTK3
* Python 3 - Yaml
* Python 3 - SQL Alchemy


## Building for Debian

```bash
make debian
```

## Author

Richard Bäck <richard.baeck@free-your-pc.com>

## License

MIT License
